==> css.csstree-0.0.1.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import defaultParserInterface from 'astql/utils/defaultParserInterface';
import pkg from 'css-tree/package.json';
var ID = 'csstree';
export default _extends({}, defaultParserInterface, {
  id: ID,
  displayName: ID,
  version: pkg.version,
  homepage: pkg.homepage || 'https://github.com/csstree/csstree',
  locationProps: new Set(['loc']),
  loadParser: function loadParser(callback) {
    require('astql/utils/multiple-require')(['css-tree'], callback);
  },
  parse: function parse(csstree, code, options) {
    return csstree.toPlainObject(csstree.parse(code, _extends({
      positions: true
    }, options)));
  },
  nodeToRange: function nodeToRange(_ref) {
    var loc = _ref.loc;

    if (loc && loc.start && loc.end) {
      return [loc.start.offset, loc.end.offset];
    }
  },
  opensByDefault: function opensByDefault(node, key) {
    return key === 'children';
  },
  getDefaultOptions: function getDefaultOptions() {
    return {
      context: 'stylesheet',
      parseValue: true,
      parseRulePrelude: true,
      parseAtrulePrelude: true,
      parseCustomProperty: false
    };
  },
  _getSettingsConfiguration: function _getSettingsConfiguration() {
    return {
      fields: [['context', ['stylesheet', 'atrule', 'atrulePrelude', 'mediaQueryList', 'mediaQuery', 'rule', 'selectorList', 'selector', 'block', 'declarationList', 'declaration', 'value']], 'parseValue', 'parseRulePrelude', 'parseAtrulePrelude', 'parseCustomProperty']
    };
  }
});

==> css.csstree-0.1.3.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import { multipleRequire } from '@astql/core';
import defaultParserInterface from '@astql/core/utils/defaultParserInterface';
import pkg from 'css-tree/package.json';
var ID = 'csstree';
export default _extends({}, defaultParserInterface, {
  id: ID,
  displayName: ID,
  version: pkg.version,
  homepage: pkg.homepage || 'https://github.com/csstree/csstree',
  locationProps: new Set(['loc']),
  loadParser: function loadParser(callback) {
    multipleRequire(['css-tree'], callback);
  },
  parse: function parse(csstree, code, options) {
    return csstree.toPlainObject(csstree.parse(code, _extends({
      positions: true
    }, options)));
  },
  nodeToRange: function nodeToRange(_ref) {
    var loc = _ref.loc;

    if (loc && loc.start && loc.end) {
      return [loc.start.offset, loc.end.offset];
    }
  },
  opensByDefault: function opensByDefault(node, key) {
    return key === 'children';
  },
  getDefaultOptions: function getDefaultOptions() {
    return {
      context: 'stylesheet',
      parseValue: true,
      parseRulePrelude: true,
      parseAtrulePrelude: true,
      parseCustomProperty: false
    };
  },
  _getSettingsConfiguration: function _getSettingsConfiguration() {
    return {
      fields: [['context', ['stylesheet', 'atrule', 'atrulePrelude', 'mediaQueryList', 'mediaQuery', 'rule', 'selectorList', 'selector', 'block', 'declarationList', 'declaration', 'value']], 'parseValue', 'parseRulePrelude', 'parseAtrulePrelude', 'parseCustomProperty']
    };
  }
});
